@@ -334,7 +334,8 @@ def params_flattened(param: Parameter):
   return addList
 
 
-def flexibleParamTree(treeParams: t.Union[t.List[Parameter], Parameter]=None, showTop=True, setTooltips=True):
+def flexibleParamTree(treeParams: t.Union[t.List[Parameter], Parameter]=None, showTop=True, setTooltips=True,
+                      resizeNameCol=True):
   tree = ParameterTree()
   tree.setTextElideMode(QtCore.Qt.ElideRight)
   tree.header().setSectionResizeMode(QtWidgets.QHeaderView.Interactive)
@@ -354,6 +355,8 @@ def flexibleParamTree(treeParams: t.Union[t.List[Parameter], Parameter]=None, sh
       desc = change[0][1]
       if 'added' in desc.lower():
         setParamTooltips(tree)
+        if resizeNameCol:
+          tree.resizeColumnToContents(0)
     param.sigTreeStateChanged.connect(maybeUpdateTips)
 
   if setTooltips:
@@ -482,7 +485,6 @@ def docParser(docstring: str):
 def paramWindow(param: Parameter):
   tree = flexibleParamTree(param)
   tree.setHeaderHidden(True)
-  tree.resizeColumnToContents(0)
   dlg = QtWidgets.QDialog()
   layout = QtWidgets.QVBoxLayout()
   dlg.setLayout(layout)
