@@ -8,7 +8,7 @@ from pyqtgraph.Qt import QtCore, QtWidgets
 from pyqtgraph.parametertree import Parameter
 from pyqtgraph.parametertree.parameterTypes import GroupParameter
 
-from utilitys.widgets import EasyWidget
+from utilitys.widgets import EasyWidget, DummySignal
 from . import PrjParam
 from .procwrapper import NestedProcWrapper
 from .. import fns
@@ -154,9 +154,26 @@ class ParamEditor(QtWidgets.QDockWidget):
 
     self._buildGui()
 
-    # Populate initial values
+    # Redefine here to avoid excess parameters and make nice name
+    def niceStateLoader(loadState='Default'):
+      """
+      :param loadState:
+        pType: popuplineeditor
+        limits: [Default]
+      """
+      if loadState in self.savedStates and loadState != self.lastAppliedName:
+        return self.loadParamValues(loadState)
+
+    proc, param = self.registerFunc(niceStateLoader, namePath=(), overrideBasePath=(), nest=False, returnParam=True,
+                                 parentParam=self._metaParamGrp, runOpts=RunOpts.ON_CHANGED)
+    self.stateSelector = param.child('loadState')
+
+    # Populate initial values, avoid early trigger of load values
     if self.saveDir:
       self.updateSavedStates()
+    else:
+      self._metaTree.hide()
+      param.hide()
 
     SPAWNED_EDITORS.append(weakref.proxy(self))
 
@@ -494,7 +511,13 @@ class ParamEditor(QtWidgets.QDockWidget):
       menu.addAction(proc.name, lambda _p=proc: _p.run())
     return menu
   
-  def updateSavedStates(self):
+  def updateSavedStates(self, blockLoad=True):
+    """
+    Evaluates this directory's saved states and exposes them to the application
+
+    :param blockLoad: It is posisble for the current state to be deleted, in which case this call will force load the
+      next possible state. When `blockLoad` is *True*, this will not happen.
+    """
     dirGlob = list(self.saveDir.glob(f'*.{self.fileType}'))
     dirStates = [f.stem for f in dirGlob]
 
@@ -502,7 +525,14 @@ class ParamEditor(QtWidgets.QDockWidget):
     delStates = set(self.savedStates) - set(newStates)
 
     self.savedStates = dirStates
-    self.stateSelector.setLimits(self.savedStates)
+    # Kind of a hack: Make sure no sigValueChange is emmittedto until after setLimits
+    oldSig = self.stateSelector.sigValueChanged
+    if blockLoad:
+      self.stateSelector.sigValueChanged = DummySignal()
+    try:
+      self.stateSelector.setLimits(self.savedStates)
+    finally:
+      self.stateSelector.sigValueChanged = oldSig
     for state in newStates:
       self.sigParamStateCreated.emit(state)
     for state in delStates:
@@ -557,21 +587,15 @@ class ParamEditor(QtWidgets.QDockWidget):
     self.saveAsBtn = QtWidgets.QPushButton('Save As...')
     self.applyBtn = QtWidgets.QPushButton('Apply')
 
-    """Shows current state or load a new one"""
-    def onReturn(param, val):
-      if val in self.savedStates and val != self.lastAppliedName:
-        self.loadParamValues(val)
-
     # -----------
     # Widget layout
     # -----------
+    self._mkMetaTree()
+
     self.treeBtnsWidget = EasyWidget([self.expandAllBtn, self.collapseAllBtn])
-    self.loadStateWidgets, self.stateSelector = EasyWidget.fromPgParam(name='Load State', type='popuplineeditor')
-    self.stateSelector.sigValueChanged.connect(onReturn)
     children = [
-      self.loadStateWidgets,
       self.treeBtnsWidget,
-      self.tree,
+      EasyWidget([self._metaTree, self.tree], layout='V', useSplitter=True),
       [self.saveAsBtn, self.applyBtn]
     ]
 
@@ -580,7 +604,6 @@ class ParamEditor(QtWidgets.QDockWidget):
     if self.saveDir is None:
       self.saveAsBtn.hide()
       self.treeBtnsWidget.widget_.hide()
-      self.loadStateWidgets.widget_.hide()
 
     self.centralLayout = self.dockContentsWidget.easyChild.layout_
     self.setWidget(self.dockContentsWidget)
@@ -596,6 +619,23 @@ class ParamEditor(QtWidgets.QDockWidget):
     self.saveAsBtn.clicked.connect(self.saveParamValues_gui)
     self.applyBtn.clicked.connect(self.applyChanges)
 
+  def _mkMetaTree(self):
+    self._metaParamGrp = Parameter.create(name='Meta Parameters', type='group')
+    self._metaTree = fns.flexibleParamTree(self._metaParamGrp, showTop=False)
+    """
+    Tree for controlling meta-parameters, useful for configuring the parameter editor itself
+    (i.e. loading state, etc.)
+    """
+    self._metaTree.setHeaderHidden(True)
+    oldSzHint = self._metaTree.sizeHint
+    def newSzHint():
+      baseHint = oldSzHint()
+      baseHint.setHeight(int(baseHint.height() * 1.1))
+      return baseHint
+    self._metaTree.sizeHint = newSzHint
+    # self._metaTree.setSizePolicy(self._metaTree.sizePolicy().horizontalPolicy(), QtWidgets.QSizePolicy.Fixed)
+    return self._metaTree, self._metaParamGrp
+
   def __repr__(self):
     selfCls = type(self)
     oldName: str = super().__repr__()
@@ -611,7 +651,6 @@ class ParamEditor(QtWidgets.QDockWidget):
       tabs: QtWidgets.QTabWidget = self.dock.tabs
       dockIdx = tabs.indexOf(self.dockContentsWidget)
       tabs.setCurrentIndex(dockIdx)
-    self.tree.resizeColumnToContents(0)
     # Necessary on MacOS
     self.dock.setWindowState(QtCore.Qt.WindowActive)
     self.dock.raise_()
@@ -665,7 +704,6 @@ class ParamEditorDockGrouping(QtWidgets.QDockWidget):
   def addEditors(self, editors: t.Sequence[ParamEditor]):
     minWidth = 0
     for editor in editors:
-      editor.tree.resizeColumnToContents(0)
       if editor.width() > minWidth:
         minWidth = int(editor.width()*0.8)
       # "Main Image Settings" -> "Settings"
